@@ -118,6 +118,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <netdb.h>
+#include <pthread.h>
 
 #include "pbs_ifl.h"
 #include "list_link.h"
@@ -486,6 +487,7 @@ job_alloc(void)
   pj->ji_globid = NULL;
   pj->ji_stdout = 0;
   pj->ji_stderr = 0;
+  pj->ji_qs.ji_un.ji_momt.ji_exitstat = 0;
 
   pj->ji_momhandle = -1;  /* mark mom connection invalid */
 
@@ -609,7 +611,7 @@ static void job_init_wattr(
 
 
 /*
- * job_purge - purge job from system
+ * job_purge_thread - purge job from system
  *
  * The job is dequeued; the job control file, script file and any spooled
  * output files are unlinked, and the job structure is freed.
@@ -617,19 +619,17 @@ static void job_init_wattr(
  * removed.
  */
 
-void job_purge(
-
-  job *pjob)  /* I (modified) */
-
+void *job_purge_thread(void *jobtopurge)
   {
-  static char   id[] = "job_purge";
-
+  static char   id[] = "job_purge_thread";
+  job *pjob;
   char          namebuf[MAXPATHLEN + 1];
   extern char  *msg_err_purgejob;
   int           rc;
-
   extern void MOMCheckRestart A_((void));
 
+  pjob = (job *)jobtopurge;
+
   if (pjob->ji_flags & MOM_HAS_TMPDIR)
     {
     if (TTmpDirName(pjob, namebuf))
@@ -648,7 +648,7 @@ void job_purge(
         {
         /* FAILURE */
 
-        return;
+        pthread_exit(NULL);
         }
 
       rc = remtree(namebuf);
@@ -778,6 +778,50 @@ void job_purge(
   if (((job *)GET_NEXT(svr_alljobs)) == NULL)
     MOMCheckRestart();
 
+  pthread_exit(NULL);
+  }
+
+void job_purge(
+
+  job *pjob)  /* I (modified) */
+
+  {
+  static char   id[] = "job_purge";
+  pthread_attr_t attr;
+  pthread_t *thread;
+  int rc;
+
+  rc = pthread_attr_init( &attr );
+  if(rc)
+    {
+    sprintf(log_buffer, "pthread_attr_init failded. job number %s", pjob->ji_qs.ji_jobid);
+    log_err(rc, id, log_buffer);
+    return;
+    }
+
+  rc = pthread_attr_setdetachstate(
+     &attr, PTHREAD_CREATE_DETACHED );
+  if(rc)
+    {
+    sprintf(log_buffer, "pthread_attr_setdetachstate failded. job number %s", pjob->ji_qs.ji_jobid);
+    log_err(rc, id, log_buffer);
+    return;
+    }
+  thread = (pthread_t *)malloc(sizeof(pthread_t));
+  if(thread == NULL) 
+    {
+    sprintf(log_buffer, "Could not allocate memory for job_purge thread");
+    log_err(errno, id, log_buffer);
+    return;
+    }
+
+  rc = pthread_create(thread, &attr, &job_purge_thread, pjob);
+  if(rc)
+    {
+    sprintf(log_buffer, "pthread_create failed: %d", rc);
+    log_err(rc, id, log_buffer);
+    }
+
   return;
   }  /* END job_purge() */
 
